@@ -127,7 +127,7 @@ from . import adapter_deepinmysoulnet
 from . import adapter_kiarepositorymujajinet
 from . import adapter_adultfanfictionorg
 from . import adapter_fictionhuntcom
-from . import adapter_royalroadl
+from . import adapter_royalroadcom
 from . import adapter_chosentwofanficcom
 from . import adapter_bdsmlibrarycom
 from . import adapter_asexstoriescom
@@ -170,7 +170,7 @@ from . import adapter_noveltrovecom
 from . import adapter_inkbunnynet
 from . import adapter_alternatehistorycom
 from . import adapter_wattpadcom
-from . import adapter_lightnovelgatecom
+from . import adapter_novelonlinefullcom
 from . import adapter_wwwnovelallcom
 from . import adapter_wuxiaworldco
 from . import adapter_harrypotterfanfictioncom
