@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Fanficdownloader team, 2015 FanFicFare team
+# Copyright 2011 Fanficdownloader team, 2018 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,19 +15,22 @@
 # limitations under the License.
 #
 
-import time
+from __future__ import absolute_import
 import datetime
 import logging
 logger = logging.getLogger(__name__)
 import re
-import urllib2
 from .. import translit
 
 
 from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
 
-from base_adapter import BaseSiteAdapter,  makeDate
+# py2 vs py3 transition
+from ..six import text_type as unicode
+from ..six.moves.urllib.error import HTTPError
+
+from .base_adapter import BaseSiteAdapter,  makeDate
 
 
 def getClass():
@@ -41,11 +44,6 @@ class FicBookNetAdapter(BaseSiteAdapter):
     def __init__(self, config, url):
         BaseSiteAdapter.__init__(self, config, url)
 
-        self.decode = ["utf8",
-                       "Windows-1252"] # 1252 is a superset of iso-8859-1.
-                               # Most sites that claim to be
-                               # iso-8859-1 (and some that claim to be
-                               # utf8) are really windows-1252.
         self.username = "NoneGiven" # if left empty, site doesn't return any message at all.
         self.password = ""
         self.is_adult=False
@@ -82,12 +80,12 @@ class FicBookNetAdapter(BaseSiteAdapter):
         logger.debug("URL: "+url)
         try:
             data = self._fetchUrl(url)
-        except urllib2.HTTPError, e:
+        except HTTPError as e:
             if e.code == 404:
                 raise exceptions.StoryDoesNotExist(self.url)
             else:
                 raise e
-				
+
 
         # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
@@ -98,9 +96,9 @@ class FicBookNetAdapter(BaseSiteAdapter):
                 adult_div.extract()
             else:
                 raise exceptions.AdultCheckRequired(self.url)
-        
+
         # Now go hunting for all the meta data and the chapter list.
-		
+
         ## Title
         a = soup.find('section',{'class':'chapter-info'}).find('h1')
         # kill '+' marks if present.
@@ -119,6 +117,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
         logger.debug("Author: (%s)"%self.story.getMetadata('author'))
 
         # Find the chapters:
+        pubdate = None
         chapters = soup.find('ul', {'class' : 'table-of-contents'})
         if chapters != None:
             chapters=chapters.findAll('a', href=re.compile(r'/readfic/'+self.story.getMetadata('storyId')+"/\d+#part_content$"))
@@ -126,15 +125,16 @@ class FicBookNetAdapter(BaseSiteAdapter):
             for x in range(0,len(chapters)):
                 chapter=chapters[x]
                 churl='https://'+self.host+chapter['href']
-                self.chapterUrls.append((stripHTML(chapter),churl))
-                if x == 0:
+                self.add_chapter(chapter,churl)
+                ## First chapter doesn't always have a date, skip it.
+                if pubdate == None and chapter.parent.find('span'):
                     pubdate = translit.translit(stripHTML(chapter.parent.find('span')))
                     # pubdate = translit.translit(stripHTML(self.make_soup(self._fetchUrl(churl)).find('div', {'class' : 'part_added'}).find('span')))
                 if x == len(chapters)-1:
                     update = translit.translit(stripHTML(chapter.parent.find('span')))
                     # update = translit.translit(stripHTML(self.make_soup(self._fetchUrl(churl)).find('div', {'class' : 'part_added'}).find('span')))
         else:
-            self.chapterUrls.append((self.story.getMetadata('title'),url))
+            self.add_chapter(self.story.getMetadata('title'),url)
             self.story.setMetadata('numChapters',1)
             pubdate=translit.translit(stripHTML(soup.find('div',{'class':'title-area'}).find('span')))
             update=pubdate
@@ -183,7 +183,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
 
 
         dlinfo = soup.find('dl',{'class':'info'})
-        
+
         i=0
         fandoms = dlinfo.find('dd').findAll('a', href=re.compile(r'/fanfiction/\w+'))
         for fandom in fandoms:
@@ -197,7 +197,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
 
         ratingdt = dlinfo.find('dt',text='Рейтинг:')
         self.story.setMetadata('rating', stripHTML(ratingdt.next_sibling))
-            
+
         # meta=table.findAll('a', href=re.compile(r'/ratings/'))
         # i=0
         # for m in meta:
@@ -209,13 +209,13 @@ class FicBookNetAdapter(BaseSiteAdapter):
         #             i=2
         #         self.story.addToList('genre', m.find('b').text)
         #     elif i == 2:
-        #         self.story.addToList('warnings', m.find('b').text)		
+        #         self.story.addToList('warnings', m.find('b').text)
 
         if dlinfo.find('span', {'style' : 'color: green'}):
             self.story.setMetadata('status', 'Completed')
         else:
             self.story.setMetadata('status', 'In-Progress')
-		
+
 
         tags = dlinfo.findAll('dt')
         for tag in tags:
@@ -225,7 +225,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
                 for char in chars:
                     self.story.addToList('characters',char)
                 break
-				
+
         summary=soup.find('div', {'class' : 'urlize'})
         self.setDescription(url,summary)
         #self.story.setMetadata('description', summary.text)
